#import "@preview/cetz:0.2.2"

#set page(margin: .5in)
#set par(leading: 0.55em, first-line-indent: 1.8em, justify: true)
#set text(font: "New Computer Modern", 14pt)
#show raw: set text(font: "New Computer Modern Mono")
#show heading: set block(above: 1.4em, below: 1em)
#show raw: set text(font: "New Computer Modern Mono", size: 13pt)

#let title(body) = {
	align(center, text(17pt)[*#body*])
}

#let myplot(..pts-style) = {
	import cetz.draw: *

	line((0,0), (6,0), mark: (end: "straight"))
	line((0,0), (0,6), mark: (end: "straight"))
	for i in range(0, 6) {
		content((i, -.5), [#i])
		line((i, 0), (i, -.2))
		content((-.5, i), [#i])
		line((0, i), (-.2, i))
	}

	set-style(
		rect: (
			fill: rgb("d4d4d4"),
		)
	)

	let pts = pts-style.pos()
	for p in pts {
		rect(p.at(0), p.at(1))
	}
}

#title[Perfect Rectangle]

Saeed is tackling a problem involving geometric shapes, specifically rectangles.
He would like to seek your assistance in understanding how to determine whether a given
set of rectangles together forms an exact cover of a rectangle region.

== Input

The first line represents the number of rectangles we have, refferred to as $i$.
The subsequent lines will consist of four integers each.

== Example 1
#grid(
	columns: (1fr, 1fr),
	[
		==== Input:

		```
		5
		1,1,3,3
		3,1,4,2
		3,2,4,4
		1,3,2,4
		2,3,3,4
		```

		==== Output:

		```
		True
		```
	],
	[
		#cetz.canvas({
			myplot(
				((1,1), (3,3)),
				((3,1), (4,2)),
				((3,2), (4,4)),
				((1,3), (2,4)),
				((2,3), (3,4))
			)
		})
	]
)

== Example 2
#grid(
	columns: (1fr, 1fr),
	[
		=== Input:

		```
		4
		1,1,2,3
		1,3,2,4
		3,1,4,2
		3,2,4,4
		```

		==== Output:

		```
		False
		```
	],
	[
		#cetz.canvas({
			myplot(
				((1,1), (2,3)),
				((1,3), (2,4)),
				((3,1), (4,2)),
				((3,2), (4,4)),
			)
		})
	]
)

#pagebreak()

== Example 2
#grid(
	columns: (1fr, 1fr),
	[
		#set table(align: (_, y) => if y == 0 { center } else { left })
		#set table(stroke: (_, y) => if y == 0 { (bottom: 1pt) })
		#table(
			columns: (1.5in, 1.5in),
			inset: 10pt,
			table.vline(x: 1),
			table.header(
				[*Input*], [*Output*]
			),
			[
				```
				4
				1,1,3,3
				3,1,4,2
				1,3,2,4
				2,2,4,4
				```
			],
			[
				```
				False
				```
			]
		)
	],
	[
		#cetz.canvas({
			import cetz.draw: *
			myplot(
				((1,1), (3,3)),
				((3,1), (4,2)),
				((1,3), (2,4)),
				((2,2), (4,4)),
			)
			rect((2,2), (3,3))
			for i in range(1, 11) {
				line((2,3-(i/10)), (2+(i/10),3));
			}
			for i in range(1, 10) {
				line((2+(i/10),2), (3,3-(i/10)));
			}
		})
	]
)
